SystemOrganization addCategory: #'FixedDecimal Tests'!

TestCase subclass: #FixedDecimalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FixedDecimal Tests'!

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 8/30/2007 20:07'!
testAddition
	| fd |

	fd := FixedDecimal newFromNumber: 18.25 scale: 2.
	self assert: ('20.00' = (fd + (1.75 asFixedDecimal: 2)) printString).
	self assert: ('20.00' = (fd + 1.75) printString).
	self assert: ('20.00' = (fd + (175/100)) printString).
	self assert: ('19.25' = (fd + 1) printString).
	self assert: ('17.25' = (fd + -1) printString).! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 9/6/2007 19:47'!
testAdoption
	| original |
	
	original := (8872240531573379/9007199254740992) asFixedDecimal: 3.
	self assert: '1.985' = ((1 + original) printString).
	self assert: '1.985' = ((original + 1) printString).
	self assert: '1.485' = ((1/2 + original) printString).
	self assert: '1.485' = ((original + (1/2)) printString).
	self assert: '1.985' = ((1.0 + original) printString).
	self assert: '1.985' = ((original + 1.0) printString).
	self assert: '1.985' = ((1s2 + original) printString).
	self assert: '1.985' = ((original + 1s2) printString).
	self assert: '1.985' = (('1' + original) printString).
	self assert: '1.985' = ((original + '1') printString).
	
! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 8/30/2007 18:57'!
testConvertFromFloat
	| aFloat fd f2 diff |

	aFloat := 11/13 asFloat.
	fd _ FixedDecimal newFromNumber: aFloat scale: 2.
	self assert: 2 == fd scale.
	self assert: '0.85' = fd printString. "Note - different than ScaledDecimal.  For ScaledDecimal
										this will equal 0.84.  Fixed decimals - we actually
										round to the scale provided - we don't want the 
										extra precision that ScaledDecimal keeps around!!"
	self assert: 85 == fd part2.
	f2 := fd asFloat.
	self assert: 0.85 = f2.
	diff := f2 - aFloat.
	"self assert: diff < 1.0e-9." "Unlike ScaledDecimal, this is NOT a reversable conversion!!"
	self assert: diff > 1.0e-9.! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 8/30/2007 18:58'!
testConvertFromFraction

	| fd |
	fd := FixedDecimal newFromNumber: (13 / 11) scale: 6.
	self assert: FixedDecimal == fd class.
	self assert: ('1.181818' = fd printString).
	self assert: 6 == fd scale
! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 8/30/2007 19:04'!
testConvertFromInteger
	"Converting an Integer to a FixedDecimal yields a FixedDecimal with
	specified scale.  This is not what happens with ScaledDecimal!!"

	| fd |
	fd := FixedDecimal newFromNumber: 13 scale: 6.
	self assert: 6 = fd scale.
	self assert: ('13.000000' = fd printString).
	fd := FixedDecimal newFromNumber: -13 scale: 6.
	self assert: 6 = fd scale.
	self assert: ('-13.000000' = fd printString).
	fd := FixedDecimal newFromNumber: 130000000013 scale: 6.
	self assert: 6 = fd scale.
	self assert: ('130000000013.000000' = fd printString).
	fd := FixedDecimal newFromNumber: -130000000013 scale: 6.
	self assert: 6 = fd scale.
	self assert: ('-130000000013.000000' = fd printString)
! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 8/30/2007 20:08'!
testDivision
	| fd |

	fd := FixedDecimal newFromNumber: 18.25 scale: 2.
	self assert: ('9.13' = (fd / (2 asFixedDecimal: 2)) printString).
	self assert: ('9.13' = (fd / 2.00) printString).
	self assert: ('9.13' = (fd / (200/100)) printString).
	self assert: ('9.13' = (fd / 2) printString).
	self assert: ('-9.13' = (fd / -2) printString).
	self assert: ('4.56' = (fd / 4) printString).! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 9/6/2007 19:07'!
testFractionPart
	
	self assert: '-0.30' = (-53/10 asFixedDecimal: 2) fractionPart printString
! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 8/30/2007 20:08'!
testMultiplication
	| fd |

	fd := FixedDecimal newFromNumber: 18.25 scale: 2.
	self assert: ('36.50' = (fd * (2 asFixedDecimal: 2)) printString).
	self assert: ('36.50' = (fd * 2.00) printString).
	self assert: ('36.50' = (fd * (200/100)) printString).
	self assert: ('36.50' = (fd * 2) printString).
	self assert: ('-36.50' = (fd * -2) printString).
	self assert: ('73.00' = (fd * 4) printString).! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 9/6/2007 19:10'!
testNegation
	| original negated |
	
	original := 53/10 asFixedDecimal: 2.
	negated := original negated.
	self assert: original ~~ negated.
	self assert: original = (negated negated).
! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 8/30/2007 20:08'!
testPrintString
	"The printed representation of a ScaledDecimal is rounded, not truncated.
	This is not compatible with the way ScaledDecimal printing works in Squeak."

	| fd |
	fd := FixedDecimal newFromNumber: (13 / 11) scale: 6.
	self assert: ('1.181818' = fd printString).
	fd := (13 / 11) asFixedDecimal: 5.
	self assert: ('1.18182' = fd printString).
	fd := FixedDecimal newFromNumber: (13 / 11) scale: 5.
	self deny: ('1.18181' = fd printString)
! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 9/6/2007 19:33'!
testReciprocal
	| original reciprocal |
	
	original := (8872240531573379/9007199254740992) asFixedDecimal: 35.
	reciprocal := original reciprocal.
	self assert: original ~~ reciprocal.
	self assert: original ~= reciprocal.
	self assert: 0 = (original * reciprocal - 1).
	original := (1/3) asFixedDecimal: 6.
	reciprocal := original reciprocal.
	self assert: original ~~ reciprocal.
	self assert: original ~= reciprocal.
	self assert: 0 = (original * reciprocal - 1).
! !

!FixedDecimalTest methodsFor: 'testing' stamp: 'cbc 8/30/2007 20:08'!
testSubtraction
	| fd |

	fd := FixedDecimal newFromNumber: 18.25 scale: 2.
	self assert: ('17.00' = (fd - (1.25 asFixedDecimal: 2)) printString).
	self assert: ('17.00' = (fd - 1.25) printString).
	self assert: ('17.00' = (fd - (125/100)) printString).
	self assert: ('17.25' = (fd - 1) printString).
	self assert: ('19.25' = (fd - -1) printString).! !
